==> apache-drill-1.21.2-src.tar.gz: apache-drill-1.21.2-src/exec/java-exec/src/main/java/org/apache/drill/exec/server/options/OptionDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.server.options;

import org.apache.drill.shaded.guava.com.google.common.base.Preconditions;

/**
 * This holds all the information about an option.
 */
public class OptionDefinition {
  private final OptionValidator validator;
  private final OptionMetaData metaData;

  public OptionDefinition(OptionValidator validator) {
    this.validator = Preconditions.checkNotNull(validator);
    this.metaData = OptionMetaData.DEFAULT;
  }

  public OptionDefinition(OptionValidator validator, OptionMetaData metaData) {
    this.validator = Preconditions.checkNotNull(validator);
    this.metaData = Preconditions.checkNotNull(metaData);
  }

  public OptionValidator getValidator() {
    return validator;
  }

  public OptionMetaData getMetaData() {
    return metaData;
  }
}

==> apache-drill-1.22.0-src.tar.gz: apache-drill-1.22.0-src/exec/java-exec/src/main/java/org/apache/drill/exec/server/options/OptionDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.server.options;

import com.google.common.base.Preconditions;

/**
 * This holds all the information about an option.
 */
public class OptionDefinition {
  private final OptionValidator validator;
  private final OptionMetaData metaData;

  public OptionDefinition(OptionValidator validator) {
    this.validator = Preconditions.checkNotNull(validator);
    this.metaData = OptionMetaData.DEFAULT;
  }

  public OptionDefinition(OptionValidator validator, OptionMetaData metaData) {
    this.validator = Preconditions.checkNotNull(validator);
    this.metaData = Preconditions.checkNotNull(metaData);
  }

  public OptionValidator getValidator() {
    return validator;
  }

  public OptionMetaData getMetaData() {
    return metaData;
  }
}
